summaryrefslogtreecommitdiffstats
path: root/gcc/tree.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/tree.c')
-rw-r--r--gcc/tree.c16
1 files changed, 12 insertions, 4 deletions
diff --git a/gcc/tree.c b/gcc/tree.c
index a48724b45d8..7ad066538d0 100644
--- a/gcc/tree.c
+++ b/gcc/tree.c
@@ -2707,8 +2707,8 @@ build_type_attribute_variant (ttype, attribute)
return ttype;
}
-/* Default value of target.valid_decl_attribute_p and
- target.valid_type_attribute_p that always returns false. */
+/* Default value of targetm.valid_decl_attribute_p and
+ targetm.valid_type_attribute_p that always returns false. */
int
default_valid_attribute_p PARAMS ((attr_name, attr_args, decl, type))
@@ -2720,7 +2720,7 @@ default_valid_attribute_p PARAMS ((attr_name, attr_args, decl, type))
return 0;
}
/* Default value of target.comp_type_attributes that always returns 1. */
int
default_comp_type_attributes (type1, type2)
@@ -2730,7 +2730,7 @@ default_comp_type_attributes (type1, type2)
return 1;
}
/* Default version of target.set_default_type_attributes that always does
nothing. */
void
@@ -2739,6 +2739,14 @@ default_set_default_type_attributes (type)
{
}
+/* Default version of targetm.insert_attributes that always does nothing. */
+void
+default_insert_attributes (decl, attr_ptr)
+ tree decl ATTRIBUTE_UNUSED;
+ tree *attr_ptr ATTRIBUTE_UNUSED;
+{
+}
+
/* Return 1 if ATTR_NAME and ATTR_ARGS is valid for either declaration
DECL or type TYPE and 0 otherwise. Validity is determined the
target functions valid_decl_attribute and valid_machine_attribute. */
@@ -2720,7 +2720,7 @@ default_valid_attribute_p PARAMS ((attr_name, attr_args, decl, type))
return 0;
}
-/* Default value of target.comp_type_attributes that always returns 1. */
+/* Default value of targetm.comp_type_attributes that always returns 1. */
int
default_comp_type_attributes (type1, type2)
@@ -2730,7 +2730,7 @@ default_comp_type_attributes (type1, type2)
return 1;
}
-/* Default version of target.set_default_type_attributes that always does
+/* Default version of targetm.set_default_type_attributes that always does
nothing. */
void
OpenPOWER on IntegriCloud